CLI configuration management
Handles loading and parsing of configuration files for the CLI tool.
Structs
- Benchmark
Config - Benchmark configuration
- CliConfig
- CLI configuration
- Client
Config - Client configuration
- DevConfig
- Development configuration
- Download
Config - Download configuration
- Model
CliConfig - Model CLI configuration
- Retry
Config - Retry configuration
- Runtime
CliConfig - Runtime knobs that can be sourced from the CLI config file.
- Server
CliConfig - Server CLI configuration