Module runtime_env

Module runtime_env 

CLI runtime environment compatibility bridge.

Product control-plane values should be represented as typed RuntimeConfigEntry values first. This module contains the small remaining bridge that materializes those entries into process env only for backend paths that have not yet been converted to typed config.

Functions

materialize_runtime_env_defaults
materialize_runtime_env_effective
moe_graph_default_entries
Default-OFF MoE CUDA graph policy for Qwen3-MoE startup profiles.
push_cli_runtime_entry
push_cli_runtime_usize
runtime_snapshot_value
warn_if_moe_graph_needs_unbuilt_vllm_moe